==> teradataml-16.20.0.1.post0-py3-none-any.whl: teradataml/analytics/mle/TextChunker.py <==
#!/usr/bin/python
# ################################################################## 
# 
# Copyright 2018 Teradata. All rights reserved.
# TERADATA CONFIDENTIAL AND TRADE SECRET
# 
# Primary Owner: Pankaj Purandare (pankajvinod.purandare@teradata.com)
# Secondary Owner: Mounika Kotha (mounika.kotha@teradata.com)
# 
# Version: 1.2
# Function Version: 1.5
# 
# ################################################################## 

from teradataml.common.wrapper_utils import AnalyticsWrapperUtils
from teradataml.common.utils import UtilFuncs
from teradataml.context.context import *
from teradataml.dataframe.dataframe import DataFrame
from teradataml.common.aed_utils import AedUtils
from teradataml.analytics.analytic_query_generator import AnalyticQueryGenerator
from teradataml.common.exceptions import TeradataMlException
from teradataml.common.messages import Messages
from teradataml.common.messagecodes import MessageCodes
from teradataml.common.constants import TeradataConstants
from teradataml.dataframe.dataframe_utils import DataFrameUtils as df_utils
from teradataml.options.display import display

class TextChunker:
    
    def __init__(self,
        data = None,
        word_column = None,
        pos_column = None,
        data_sequence_column = None,
        data_partition_column = "1",
        data_order_column = None) :
        """
        DESCRIPTION:
            The TextChunker function divides text into phrases and assigns each 
            phrase a tag that identifies its type.        
        
        PARAMETERS:
            data:
                Required Argument.
                Specifies the teradataml DataFrame that contains the text to be 
                scanned.
            
            data_partition_column:
                Optional Argument.
                Specifies Partition By columns for data.
                Values to this argument can be provided as list, if multiple 
                columns are used for partition.
                Default Value: 1
                Types: str OR list of Strings (str)
            
            data_order_column:
                Required Argument.
                Specifies Order By columns for data.
                Values to this argument can be provided as list, if multiple 
                columns are used for ordering.
                Types: str OR list of Strings (str)
            
            word_column:
                Required Argument.
                Specifies the name of the input teradataml DataFrame column that 
                contains the words to chunk into phrases. Typically, this is the
                word column of the output teradataml DataFrame of the "PosTagger"
                function.
                Types: str
            
            pos_column:
                Required Argument.
                Specifies the name of the input teradataml DataFrame column the 
                part-of-speech (POS) tag of words. Typically, this is the pos_tag 
                column of the output teradataml DataFrame of the "PosTagger"
                function
                Types: str
            
            data_sequence_column:
                Optional Argument.
                Specifies the list of column(s) that uniquely identifies each 
                row of the input argument "data". The argument is used to ensure 
                deterministic results for functions which produce results that 
                vary from run to run.
                Types: str OR list of Strings (str)
        
        RETURNS:
            Instance of TextChunker.
            Output teradataml DataFrames can be accessed using attribute 
            references, such as TextChunkerObj.<attribute_name>.
            Output teradataml DataFrame attribute name is:
                result
        
        RAISES:
            TeradataMlException
        
        
        EXAMPLES:
            # Load example data.
            load_example_data("textchunker", "posttagger_output")

            # Create teradataml DataFrame objects.
            # "posttagger_output" is the ouput of POSTagger function.
            posttagger_output = DataFrame.from_table("posttagger_output")

            # Example 1 - This example uses the persisted output of POSTagger 
            # as Input.
            textchunker_out =TextChunker(data=posttagger_output,
                                         data_order_column=['paraid','word_sn'],
                                         word_column='word',
                                         pos_column='pos_tag',
                                         data_sequence_column='paraid',
                                         data_partition_column='paraid'
                                         )
            
            # Print the result DataFrame
            print(textchunker_out)

            # Load the data to run the example.
            load_example_data("postagger","paragraphs_input")
            
            # Create input teradataml dataframe.
            paragraphs_input = DataFrame.from_table("paragraphs_input")

            
            # Example 2 - This example uses output of SentenceExtractor and POSTagger
            # as Input.
            sentenceextractor_out = SentenceExtractor(data=paragraphs_input,
                                                      text_column='paratext',
                                                      accumulate='paraid'
                                                      )
            
            se_res = sentenceextractor_out.result            
            sentenceextractor_out = se_res.assign(True,sentence_id = se_res.paraid*1000+se_res.sentence_sn, 
                                                  sentence = se_res.sentence)
            
            pos_tagger_out = POSTagger(data=sentenceextractor_out,
                               text_column='sentence',
                               accumulate='sentence_id')
            
            textchunker_out =TextChunker(data=pos_tagger_out.result,
                                         data_order_column='word_sn',
                                         word_column='word',
                                         pos_column='pos_tag')
            
            # Print the result DataFrame
            print(textchunker_out)
        """
        self.data  = data 
        self.word_column  = word_column 
        self.pos_column  = pos_column 
        self.data_sequence_column  = data_sequence_column 
        self.data_partition_column  = data_partition_column 
        self.data_order_column  = data_order_column 
        
        # Create TeradataPyWrapperUtils instance which contains validation functions.
        self.__awu = AnalyticsWrapperUtils()
        self.__aed_utils = AedUtils()
        
        # Create argument information matrix to do parameter checking
        self.__arg_info_matrix = []
        self.__arg_info_matrix.append(["data", self.data, False, (DataFrame)])
        self.__arg_info_matrix.append(["data_partition_column", self.data_partition_column, True, (str,list)])
        self.__arg_info_matrix.append(["data_order_column", self.data_order_column, False, (str,list)])
        self.__arg_info_matrix.append(["word_column", self.word_column, False, (str)])
        self.__arg_info_matrix.append(["pos_column", self.pos_column, False, (str)])
        self.__arg_info_matrix.append(["data_sequence_column", self.data_sequence_column, True, (str,list)])
        
        # Perform the function validations
        self.__validate()
        # Generate the ML query
        self.__form_tdml_query()
        # Process output table schema
        self.__process_output_column_info()
        # Execute ML query
        self.__execute()
        
    def __validate(self) :
        """
        Function to validate sqlmr function arguments, which verifies missing 
        arguments, input argument and table types. Also processes the 
        argument values.
        """
        
        # Make sure that a non-NULL value has been supplied for all mandatory arguments
        self.__awu._validate_missing_required_arguments(self.__arg_info_matrix)
        
        # Make sure that a non-NULL value has been supplied correct type of argument
        self.__awu._validate_argument_types(self.__arg_info_matrix)
        
        # Check to make sure input table types are strings or data frame objects or of valid type.
        self.__awu._validate_input_table_datatype(self.data, "data", None)
        
        # Check whether the input columns passed to the argument are not empty.
        # Also check whether the input columns passed to the argument valid or not.
        self.__awu._validate_input_columns_not_empty(self.word_column, "word_column")
        self.__awu._validate_dataframe_has_argument_columns(self.word_column, "word_column", self.data, "data", False)
        
        self.__awu._validate_input_columns_not_empty(self.pos_column, "pos_column")
        self.__awu._validate_dataframe_has_argument_columns(self.pos_column, "pos_column", self.data, "data", False)
        
        self.__awu._validate_input_columns_not_empty(self.data_sequence_column, "data_sequence_column")
        self.__awu._validate_dataframe_has_argument_columns(self.data_sequence_column, "data_sequence_column", self.data, "data", False)
        
        self.__awu._validate_input_columns_not_empty(self.data_partition_column, "data_partition_column")
        if self.__awu._is_default_or_not(self.data_partition_column, "1"):
            self.__awu._validate_dataframe_has_argument_columns(self.data_partition_column, "data_partition_column", self.data, "data", True)
        
        self.__awu._validate_input_columns_not_empty(self.data_order_column, "data_order_column")
        self.__awu._validate_dataframe_has_argument_columns(self.data_order_column, "data_order_column", self.data, "data", False)
        
        
    def __form_tdml_query(self) :
        """
        Function to generate the analytical function queries. The function defines 
        variables and list of arguments required to form the query.
        """
        
        # Output table arguments list
        self.__func_output_args_sql_names = []
        self.__func_output_args = []
        
        # Generate lists for rest of the function arguments
        self.__func_other_arg_sql_names = []
        self.__func_other_args = []
        self.__func_other_arg_json_datatypes = []
        
        self.__func_other_arg_sql_names.append("WordColumn")
        self.__func_other_args.append(UtilFuncs._teradata_collapse_arglist(UtilFuncs._teradata_quote_arg(self.word_column,"\""),"'"))
        self.__func_other_arg_json_datatypes.append("COLUMNS")
        
        self.__func_other_arg_sql_names.append("PosColumn")
        self.__func_other_args.append(UtilFuncs._teradata_collapse_arglist(UtilFuncs._teradata_quote_arg(self.pos_column,"\""),"'"))
        self.__func_other_arg_json_datatypes.append("COLUMNS")
        
        # Generate lists for rest of the function arguments
        sequence_input_by_list = []
        if self.data_sequence_column is not None:
            sequence_input_by_list.append("input:" + UtilFuncs._teradata_collapse_arglist(self.data_sequence_column,""))
        
        if len(sequence_input_by_list) > 0:
            self.__func_other_arg_sql_names.append("SequenceInputBy")
            self.__func_other_args.append(UtilFuncs._teradata_collapse_arglist(sequence_input_by_list,"'"))
            self.__func_other_arg_json_datatypes.append("STRING")
        
        
        # Declare empty lists to hold input table information.
        self.__func_input_arg_sql_names = []
        self.__func_input_table_view_query = []
        self.__func_input_dataframe_type = []
        self.__func_input_distribution = []
        self.__func_input_partition_by_cols = []
        self.__func_input_order_by_cols = []
        
        # Process data
        if self.__awu._is_default_or_not(self.data_partition_column, "1"):
            self.data_partition_column = UtilFuncs._teradata_collapse_arglist(self.data_partition_column,"\"")
        self.__table_ref = self.__awu._teradata_on_clause_from_dataframe(self.data)
        self.__func_input_distribution.append("FACT")
        self.__func_input_arg_sql_names.append("input")
        self.__func_input_table_view_query.append(self.__table_ref["ref"])
        self.__func_input_dataframe_type.append(self.__table_ref["ref_type"])
        self.__func_input_partition_by_cols.append(self.data_partition_column)
        self.__func_input_order_by_cols.append(UtilFuncs._teradata_collapse_arglist(self.data_order_column,"\""))
        
        function_name = "TextChunker"
        # Create instance to generate SQLMR.
        aqg_obj = AnalyticQueryGenerator(function_name 
                ,self.__func_input_arg_sql_names 
                ,self.__func_input_table_view_query 
                ,self.__func_input_dataframe_type 
                ,self.__func_input_distribution 
                ,self.__func_input_partition_by_cols 
                ,self.__func_input_order_by_cols 
                ,self.__func_other_arg_sql_names 
                ,self.__func_other_args 
                ,self.__func_other_arg_json_datatypes 
                ,self.__func_output_args_sql_names 
                ,self.__func_output_args)
        # Invoke call to SQL-MR generation.
        self.sqlmr_query = aqg_obj._gen_sqlmr_select_stmt_sql()
        
        # Print SQL-MR query if requested to do so.
        if display.print_sqlmr_query:
            print(self.sqlmr_query)
        
    def __execute(self) :
        """
        Function to generate AED nodes for output tables.
        This makes a call aed_ml_query() and then output table dataframes are created.
        """
        # Create a list of input node ids contributing to a query.
        self.__input_nodeids = []
        self.__input_nodeids.append(self.data._nodeid)
        
        # Generate STDOUT table name and add it to the output table list.
        sqlmr_stdout_temp_tablename = UtilFuncs._generate_temp_table_name(prefix = "td_sqlmr_out_", use_default_database = True, gc_on_quit = True, quote=False)
        self.__func_output_args.insert(0, sqlmr_stdout_temp_tablename)
        try:
            # Call aed_ml_query and generate AED nodes.
            node_id_list = self.__aed_utils._aed_ml_query(self.__input_nodeids, self.sqlmr_query, self.__func_output_args, "TextChunker")
        except Exception as emsg:
            raise TeradataMlException(Messages.get_message(MessageCodes.AED_EXEC_FAILED, str(emsg)), MessageCodes.AED_EXEC_FAILED)
        
        
        # Update output table data frames.
        self._mlresults = []
        self.result = self.__awu._create_data_set_object(df_input=node_id_list[0], metaexpr=UtilFuncs._get_metaexpr_using_columns(node_id_list[0], self.__stdout_column_info))
        self._mlresults.append(self.result)
        
    def __process_output_column_info(self) :
        """ 
        Function to process the output schema for all the ouptut tables.
        This function generates list of column names and column types
        for each generated output tables, which can be used to create metaexpr.
        """
        # Collecting STDOUT output column information.
        stdout_column_info_name = []
        stdout_column_info_type = []
        stdout_column_info_name.append("partition_key")
        stdout_column_info_type.append(self.__awu._get_json_to_sqlalchemy_mapping("integer"))
        
        stdout_column_info_name.append("chunk_sn")
        stdout_column_info_type.append(self.__awu._get_json_to_sqlalchemy_mapping("integer"))
        
        stdout_column_info_name.append("chunk")
        stdout_column_info_type.append(self.__awu._get_json_to_sqlalchemy_mapping("VARCHAR"))
        
        stdout_column_info_name.append("chunk_tag")
        stdout_column_info_type.append(self.__awu._get_json_to_sqlalchemy_mapping("VARCHAR"))
        
        self.__stdout_column_info = zip(stdout_column_info_name, stdout_column_info_type)
        
    def __repr__(self) :
        """
        Returns the string representation for a TextChunker class instance.
        """
        repr_string="############ STDOUT Output ############"
        repr_string = "{}\n\n{}".format(repr_string,self.result)
        return repr_string

==> teradataml-16.20.0.4-py3-none-any.whl: teradataml/analytics/mle/TextChunker.py <==
#!/usr/bin/python
# ################################################################## 
# 
# Copyright 2018 Teradata. All rights reserved.
# TERADATA CONFIDENTIAL AND TRADE SECRET
# 
# Primary Owner: Pankaj Purandare (pankajvinod.purandare@teradata.com)
# Secondary Owner: Mounika Kotha (mounika.kotha@teradata.com)
# 
# Version: 1.2
# Function Version: 1.6
# 
# ################################################################## 

import inspect
from teradataml.common.wrapper_utils import AnalyticsWrapperUtils
from teradataml.common.utils import UtilFuncs
from teradataml.context.context import *
from teradataml.dataframe.dataframe import DataFrame
from teradataml.common.aed_utils import AedUtils
from teradataml.analytics.analytic_query_generator import AnalyticQueryGenerator
from teradataml.common.exceptions import TeradataMlException
from teradataml.common.messages import Messages
from teradataml.common.messagecodes import MessageCodes
from teradataml.common.constants import TeradataConstants
from teradataml.dataframe.dataframe_utils import DataFrameUtils as df_utils
from teradataml.options.display import display

class TextChunker:
    
    def __init__(self,
        data = None,
        word_column = None,
        pos_column = None,
        data_sequence_column = None,
        data_partition_column = None,
        data_order_column = None):
        """
        DESCRIPTION:
            The TextChunker function divides text into phrases and assigns each
            phrase a tag that identifies its type.

        PARAMETERS:
            data:
                Required Argument.
                Specifies the teradataml DataFrame that contains the text to be
                scanned.

            data_partition_column:
                Required Argument.
                Specifies Partition By columns for data.
                Values to this argument can be provided as list, if multiple
                columns are used for partition.
                Types: str OR list of Strings (str)

            data_order_column:
                Required Argument.
                Specifies Order By columns for data.
                Values to this argument can be provided as list, if multiple
                columns are used for ordering.
                Types: str OR list of Strings (str)

            word_column:
                Required Argument.
                Specifies the name of the input teradataml DataFrame column that
                contains the words to chunk into phrases. Typically, this is the
                word column of the output teradataml DataFrame of the "PosTagger"
                function.
                Types: str

            pos_column:
                Required Argument.
                Specifies the name of the input teradataml DataFrame column the
                part-of-speech (POS) tag of words. Typically, this is the pos_tag
                column of the output teradataml DataFrame of the "PosTagger"
                function
                Types: str

            data_sequence_column:
                Optional Argument.
                Specifies the list of column(s) that uniquely identifies each
                row of the input argument "data". The argument is used to ensure
                deterministic results for functions which produce results that
                vary from run to run.
                Types: str OR list of Strings (str)

        RETURNS:
            Instance of TextChunker.
            Output teradataml DataFrames can be accessed using attribute
            references, such as TextChunkerObj.<attribute_name>.
            Output teradataml DataFrame attribute name is:
                result

        RAISES:
            TeradataMlException


        EXAMPLES:
            # Load example data.
            load_example_data("textchunker", "posttagger_output")

            # Create teradataml DataFrame objects.
            # "posttagger_output" is the ouput of POSTagger function.
            posttagger_output = DataFrame.from_table("posttagger_output")

            # Example 1 - This example uses the persisted output of POSTagger
            # as Input.
            textchunker_out =TextChunker(data=posttagger_output,
                                         data_order_column=['paraid','word_sn'],
                                         word_column='word',
                                         pos_column='pos_tag',
                                         data_sequence_column='paraid',
                                         data_partition_column='paraid'
                                         )

            # Print the result DataFrame
            print(textchunker_out)

            # Load the data to run the example.
            load_example_data("postagger","paragraphs_input")

            # Create input teradataml dataframe.
            paragraphs_input = DataFrame.from_table("paragraphs_input")


            # Example 2 - This example uses output of SentenceExtractor and POSTagger
            # as Input.
            sentenceextractor_out = SentenceExtractor(data=paragraphs_input,
                                                      text_column='paratext',
                                                      accumulate='paraid'
                                                      )

            se_res = sentenceextractor_out.result
            sentenceextractor_out = se_res.assign(True,sentence_id = se_res.paraid*1000+se_res.sentence_sn,
                                                  sentence = se_res.sentence)

            pos_tagger_out = POSTagger(data=sentenceextractor_out,
                               text_column='sentence',
                               accumulate='sentence_id')

            textchunker_out =TextChunker(data=pos_tagger_out.result,
                                         data_partition_column='word_sn',
                                         data_order_column='word_sn',
                                         word_column='word',
                                         pos_column='pos_tag')

            # Print the result DataFrame
            print(textchunker_out)
        """
        self.data  = data 
        self.word_column  = word_column 
        self.pos_column  = pos_column 
        self.data_sequence_column  = data_sequence_column 
        self.data_partition_column  = data_partition_column 
        self.data_order_column  = data_order_column 
        
        # Create TeradataPyWrapperUtils instance which contains validation functions.
        self.__awu = AnalyticsWrapperUtils()
        self.__aed_utils = AedUtils()
        
        # Create argument information matrix to do parameter checking
        self.__arg_info_matrix = []
        self.__arg_info_matrix.append(["data", self.data, False, (DataFrame)])
        self.__arg_info_matrix.append(["data_partition_column", self.data_partition_column, False, (str,list)])
        self.__arg_info_matrix.append(["data_order_column", self.data_order_column, False, (str,list)])
        self.__arg_info_matrix.append(["word_column", self.word_column, False, (str)])
        self.__arg_info_matrix.append(["pos_column", self.pos_column, False, (str)])
        self.__arg_info_matrix.append(["data_sequence_column", self.data_sequence_column, True, (str,list)])
        
        if inspect.stack()[1][3] != '_from_model_manager':
            # Perform the function validations
            self.__validate()
            # Generate the ML query
            self.__form_tdml_query()
            # Execute ML query
            self.__execute()
        
    def __validate(self):
        """
        Function to validate sqlmr function arguments, which verifies missing 
        arguments, input argument and table types. Also processes the 
        argument values.
        """
        
        # Make sure that a non-NULL value has been supplied for all mandatory arguments
        self.__awu._validate_missing_required_arguments(self.__arg_info_matrix)
        
        # Make sure that a non-NULL value has been supplied correct type of argument
        self.__awu._validate_argument_types(self.__arg_info_matrix)
        
        # Check to make sure input table types are strings or data frame objects or of valid type.
        self.__awu._validate_input_table_datatype(self.data, "data", None)
        
        # Check whether the input columns passed to the argument are not empty.
        # Also check whether the input columns passed to the argument valid or not.
        self.__awu._validate_input_columns_not_empty(self.word_column, "word_column")
        self.__awu._validate_dataframe_has_argument_columns(self.word_column, "word_column", self.data, "data", False)
        
        self.__awu._validate_input_columns_not_empty(self.pos_column, "pos_column")
        self.__awu._validate_dataframe_has_argument_columns(self.pos_column, "pos_column", self.data, "data", False)
        
        self.__awu._validate_input_columns_not_empty(self.data_sequence_column, "data_sequence_column")
        self.__awu._validate_dataframe_has_argument_columns(self.data_sequence_column, "data_sequence_column", self.data, "data", False)
        
        self.__awu._validate_input_columns_not_empty(self.data_partition_column, "data_partition_column")
        self.__awu._validate_dataframe_has_argument_columns(self.data_partition_column, "data_partition_column", self.data, "data", False)
        
        self.__awu._validate_input_columns_not_empty(self.data_order_column, "data_order_column")
        self.__awu._validate_dataframe_has_argument_columns(self.data_order_column, "data_order_column", self.data, "data", False)
        
        
    def __form_tdml_query(self):
        """
        Function to generate the analytical function queries. The function defines 
        variables and list of arguments required to form the query.
        """
        
        # Output table arguments list
        self.__func_output_args_sql_names = []
        self.__func_output_args = []
        
        # Generate lists for rest of the function arguments
        self.__func_other_arg_sql_names = []
        self.__func_other_args = []
        self.__func_other_arg_json_datatypes = []
        
        self.__func_other_arg_sql_names.append("WordColumn")
        self.__func_other_args.append(UtilFuncs._teradata_collapse_arglist(UtilFuncs._teradata_quote_arg(self.word_column,"\""),"'"))
        self.__func_other_arg_json_datatypes.append("COLUMNS")
        
        self.__func_other_arg_sql_names.append("PosColumn")
        self.__func_other_args.append(UtilFuncs._teradata_collapse_arglist(UtilFuncs._teradata_quote_arg(self.pos_column,"\""),"'"))
        self.__func_other_arg_json_datatypes.append("COLUMNS")
        
        # Generate lists for rest of the function arguments
        sequence_input_by_list = []
        if self.data_sequence_column is not None:
            sequence_input_by_list.append("input:" + UtilFuncs._teradata_collapse_arglist(self.data_sequence_column,""))
        
        if len(sequence_input_by_list) > 0:
            self.__func_other_arg_sql_names.append("SequenceInputBy")
            self.__func_other_args.append(UtilFuncs._teradata_collapse_arglist(sequence_input_by_list,"'"))
            self.__func_other_arg_json_datatypes.append("STRING")
        
        
        # Declare empty lists to hold input table information.
        self.__func_input_arg_sql_names = []
        self.__func_input_table_view_query = []
        self.__func_input_dataframe_type = []
        self.__func_input_distribution = []
        self.__func_input_partition_by_cols = []
        self.__func_input_order_by_cols = []
        
        # Process data
        self.data_partition_column = UtilFuncs._teradata_collapse_arglist(self.data_partition_column,"\"")
        self.__table_ref = self.__awu._teradata_on_clause_from_dataframe(self.data, False)
        self.__func_input_distribution.append("FACT")
        self.__func_input_arg_sql_names.append("input")
        self.__func_input_table_view_query.append(self.__table_ref["ref"])
        self.__func_input_dataframe_type.append(self.__table_ref["ref_type"])
        self.__func_input_partition_by_cols.append(self.data_partition_column)
        self.__func_input_order_by_cols.append(UtilFuncs._teradata_collapse_arglist(self.data_order_column,"\""))
        
        function_name = "TextChunker"
        # Create instance to generate SQLMR.
        aqg_obj = AnalyticQueryGenerator(function_name 
                ,self.__func_input_arg_sql_names 
                ,self.__func_input_table_view_query 
                ,self.__func_input_dataframe_type 
                ,self.__func_input_distribution 
                ,self.__func_input_partition_by_cols 
                ,self.__func_input_order_by_cols 
                ,self.__func_other_arg_sql_names 
                ,self.__func_other_args 
                ,self.__func_other_arg_json_datatypes 
                ,self.__func_output_args_sql_names 
                ,self.__func_output_args 
                ,engine = "ENGINE_ML")
        # Invoke call to SQL-MR generation.
        self.sqlmr_query = aqg_obj._gen_sqlmr_select_stmt_sql()
        
        # Print SQL-MR query if requested to do so.
        if display.print_sqlmr_query:
            print(self.sqlmr_query)
        
    def __execute(self):
        """
        Function to execute SQL-MR queries. 
        Create DataFrames for the required SQL-MR outputs.
        """
        # Generate STDOUT table name and add it to the output table list.
        sqlmr_stdout_temp_tablename = UtilFuncs._generate_temp_table_name(prefix = "td_sqlmr_out_", use_default_database = True, gc_on_quit = True, quote=False)
        try:
            UtilFuncs._create_view(sqlmr_stdout_temp_tablename, self.sqlmr_query)
        except Exception as emsg:
            raise TeradataMlException(Messages.get_message(MessageCodes.TDMLDF_EXEC_SQL_FAILED, str(emsg)), MessageCodes.TDMLDF_EXEC_SQL_FAILED)
        
        # Update output table data frames.
        self._mlresults = []
        self.result = self.__awu._create_data_set_object(df_input=UtilFuncs._extract_table_name(sqlmr_stdout_temp_tablename), source_type="table", database_name=UtilFuncs._extract_db_name(sqlmr_stdout_temp_tablename))
        self._mlresults.append(self.result)
        
    @classmethod
    def _from_model_manager(cls,
        result = None,
        **kwargs):
        """
        Classmethod which will be used by Model Manager, to instantiate this wrapper class.
        """
        kwargs.pop("result", None)
        
        # Let's create an object of this class.
        obj = cls(**kwargs)
        obj.result  = result 
        
        # Update output table data frames.
        obj._mlresults = []
        obj.result = obj.__awu._create_data_set_object(df_input=UtilFuncs._extract_table_name(obj.result), source_type="table", database_name=UtilFuncs._extract_db_name(obj.result))
        obj._mlresults.append(obj.result)
        return obj
        
    def __repr__(self):
        """
        Returns the string representation for a TextChunker class instance.
        """
        repr_string="############ STDOUT Output ############"
        repr_string = "{}\n\n{}".format(repr_string,self.result)
        return repr_string
